@@ -62,7 +62,7 @@ import Data.Data.Lens (biplate)
 import Data.Monoid ((<>))
 import Data.Text (Text)
 import qualified Data.Text as T
-import Options.Applicative.Builder (auto, help, infoOption, long, short)
+import Options.Applicative.Builder (auto, help, hidden, infoOption, long, short)
 import Options.Applicative.Types (Parser, ReadM(..))
 import Text.PrettyPrint.ANSI.Leijen (Doc, (<+>), hardline, text)
 
@@ -84,12 +84,13 @@ warranty name = text name <+> text "comes with ABSOLUTELY NO WARRANTY." <+>
      text "This is free software, and you are welcome to redistribute it" <+>
      text "under certain conditions."
 
-versioner :: Parser (a -> a)
+versioner :: String -> Parser (a -> a)
 {-# INLINE versioner #-}
-versioner = infoOption (showVersion version) $
+versioner name = infoOption (name ++ " (hopenpgp-tools) " ++ showVersion version) $
     long "version"
    <> short 'V'
    <> help "Show version information"
+   <> hidden
 
 prependAuto :: Read a => String -> ReadM a
 prependAuto s = ReadM (local (s++) (unReadM auto))
